# %%
import os
import psutil
import pathlib
from scipy import sparse
from sklearn.cluster import AffinityPropagation
from skapex import LeveragedAffinityPropagation
from sklearn.metrics.pairwise import cosine_similarity
import numpy as np

# %%
N_SAMPLES = 20000

# %%
def human(bytes):
    for unit in ["Bytes", "KB", "MB", "GB", "TB", "PB"]:
        if bytes < 1024.0 or unit=="GB":
            return f"{bytes:.2f}{unit}"
        bytes /= 1024.0

# %%
process = psutil.Process()
peakmem = {}
def measure_peakmem(tag: str):
    peakmem[tag] = process.memory_info().peak_wset
    print(f"peakmem[{tag}]: {human(peakmem[tag])}")

# %%
measure_peakmem("base")

# %%
TFIDF = pathlib.Path("./interim/tfidf.npz")
X = sparse.load_npz(TFIDF)
X.shape
measure_peakmem("load_dataset")
print("Diff:", human(peakmem["load_dataset"] - peakmem["base"]))
print("Dataset nbytes size", human(X.data.nbytes))

# %%
S = cosine_similarity(X[:N_SAMPLES], X[:N_SAMPLES], dense_output=True)
measure_peakmem("sim")
print("Similarity matrix nbytes size", human(S.data.nbytes))

# %%
ap = AffinityPropagation(damping=0.9, max_iter=1000, preference=-2, convergence_iter=30, affinity="precomputed", random_state=0)
ap.fit(S)

# %%
measure_peakmem("fit ap")

# %%
len(ap.cluster_centers_indices_)

# %%
import pickle
pickle.dump(ap, open(f"results/affinty_propagation_{N_SAMPLES}.pkl", "wb"))

# %%



