# %%
import os
import psutil
import pathlib
from scipy import sparse
from sklearn.cluster import AffinityPropagation
from skapex import LeveragedAffinityPropagation
from sklearn.metrics.pairwise import cosine_similarity
import numpy as np

# %%
N_SAMPLES = 20000

# %%
def human(bytes):
    for unit in ["Bytes", "KB", "MB", "GB", "TB", "PB"]:
        if bytes < 1024.0 or unit=="GB":
            return f"{bytes:.2f}{unit}"
        bytes /= 1024.0

# %%
process = psutil.Process()
peakmem = {}
def measure_peakmem(tag: str):
    peakmem[tag] = process.memory_info().peak_wset
    print(f"peakmem[{tag}]: {human(peakmem[tag])}")

# %%
measure_peakmem("base")

# %%
TFIDF = pathlib.Path("./interim/tfidf.npz")
X = sparse.load_npz(TFIDF)
print(X.shape)
measure_peakmem("load_dataset")
print("Diff:", human(peakmem["load_dataset"] - peakmem["base"]))
print("Dataset nbytes size", human(X.data.nbytes))

# %%
lap = LeveragedAffinityPropagation(simf=cosine_similarity, fraction=0.02, sweeps=10, damping=0.9, max_iter=1000, p=-2, convergence_iter=30, random_state=0)
lap.fit(X[:N_SAMPLES])

# %%
measure_peakmem("fit lap")

# %%
len(lap.cluster_centers_indices_)

# %%
import pickle
pickle.dump(lap, open(f"results/leveraged_affinty_propagation_{N_SAMPLES}.pkl", "wb"))

# %%



