import numpy as np
from joblib import Memory
from pathlib import Path

from urllib.request import urlretrieve
from sklearn.datasets._base import get_data_home
import os
import gzip
import numpy as np

from sklearn.datasets import (
    make_blobs,
    fetch_openml,
    fetch_olivetti_faces,
)
from sklearn.preprocessing import MaxAbsScaler
from sklearn.model_selection import train_test_split

# memory location for caching datasets
M = Memory(location=str(Path(__file__).resolve().parent / "cache"))



@M.cache
def _blobs_dataset(n_samples=500000, n_features=3, n_clusters=100, dtype=np.float32):
    X, y = make_blobs(
        n_samples=n_samples, n_features=n_features, centers=n_clusters, random_state=0
    )
    X = X.astype(dtype, copy=False)

    X, X_val, y, y_test = train_test_split(X, y, test_size=0.1, random_state=0)
    return X, X_val, y, y_test


@M.cache
def _olivetti_faces_dataset():
    dataset = fetch_olivetti_faces(shuffle=True, random_state=42)
    faces = dataset.data
    n_samples, n_features = faces.shape
    faces_centered = faces - faces.mean(axis=0)
    # local centering
    faces_centered -= faces_centered.mean(axis=1).reshape(n_samples, -1)
    X = faces_centered
    y = dataset.target

    X, X_val,y, y_val = train_test_split(X,y, test_size=0.1, random_state=0)
    return X, X_val, y, y_val

@M.cache
def _mnist_fashion_dataset():
    import logging
    logging.warn(os.getcwd())

    data_home = os.path.join(os.getcwd(), "scikit-learn-datasets")
    if not os.path.exists(data_home):
        os.makedirs(data_home)
    urlretrieve("http://fashion-mnist.s3-website.eu-central-1.amazonaws.com/train-images-idx3-ubyte.gz", os.path.join(data_home, "train-images-idx3-ubyte.gz"))
    urlretrieve("http://fashion-mnist.s3-website.eu-central-1.amazonaws.com/train-labels-idx1-ubyte.gz", os.path.join(data_home, "train-labels-idx1-ubyte.gz"))

    def load_mnist(kind='train'):
        """Load MNIST data from `path`"""
        labels_path = os.path.join(data_home,
                                '%s-labels-idx1-ubyte.gz'
                                % kind)
        images_path = os.path.join(data_home,
                                '%s-images-idx3-ubyte.gz'
                                % kind)

        with gzip.open(labels_path, 'rb') as lbpath:
            labels = np.frombuffer(lbpath.read(), dtype=np.uint8,
                                offset=8)

        with gzip.open(images_path, 'rb') as imgpath:
            images = np.frombuffer(imgpath.read(), dtype=np.uint8,
                                offset=16).reshape(len(labels), 784)        
        return images, labels
    X, y = load_mnist('train')
    # X_val, y_val = load_mnist('test')
    return X, None, y, None
