#!/bin/bash
set -e -u -x

function repair_wheel {
    wheel="$1"
    if ! auditwheel show "$wheel"; then
        echo "Skipping non-platform wheel $wheel"
    else
        auditwheel repair "$wheel" --plat "$PLAT" -w /io/wheelhouse/
    fi
}

# Compile wheels
for PYBIN in /opt/python/*/bin; do
    if [[ $PYBIN =~ "pypy" || $PYBIN =~ "36" ]]; then
        echo "Skipping PYPY wheel for $PYBIN"
    else
        # "${PYBIN}/pip" install -r /io/dev-requirements.txt
        "${PYBIN}/pip" wheel /io/ --no-deps -w wheelhouse/
    fi
done

# Bundle external shared libraries into the wheels
for whl in wheelhouse/*.whl; do
    repair_wheel "$whl"
done

# Install packages and test
for PYBIN in /opt/python/*/bin/; do
    if [[ $PYBIN =~ "pypy" || $PYBIN =~ "36" ]]; then
        echo "Skipping PYPY wheel for $PYBIN"
    else
        "${PYBIN}/pip" install scikit-learn>=1.0.2
        "${PYBIN}/pip" install skapex --no-index -f /io/wheelhouse
        "${PYBIN}/python" io/ci/test.py
    fi
done
